/**
 * PETALS - PETALS Services Platform. Copyright (c) 2007 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */
package org.ow2.petals.bc.ftp.connection;

import org.ow2.petals.bc.ftp.FTPConstants;
import org.ow2.petals.bc.ftp.MissingElementException;
import org.ow2.petals.component.framework.api.configuration.ConfigurationExtensions;
import org.ow2.petals.component.framework.util.XMLUtil;
import org.w3c.dom.Node;

/**
 * 
 * @author alouis
 * 
 */
public class FTPConnectionInfoBuilder {

    public static FTPConnectionInfo buildFTPConnectionInfo(Node node, int attempt, long delay)
            throws MissingElementException {
        Node server = null;
        Node user = null;
        Node password = null;
        Node directory = null;
        Node port = null;
        Node connectionMode = null;
        Node transferType = null;
        Node deleteProcessedFile = null;
        server = XMLUtil.findChild(node, FTPConstants.FTP_SERVER, null, false);
        port = XMLUtil.findChild(node, FTPConstants.FTP_PORT, null, false);
        user = XMLUtil.findChild(node, FTPConstants.FTP_USER, null, false);
        password = XMLUtil.findChild(node, FTPConstants.FTP_PASSWORD, null, false);
        directory = XMLUtil.findChild(node, FTPConstants.FTP_FOLDER, null, false);
        connectionMode = XMLUtil.findChild(node, FTPConstants.CONNECTION_MODE, null, false);
        transferType = XMLUtil.findChild(node, FTPConstants.TRANSFER_TYPE, null, false);
        deleteProcessedFile = XMLUtil.findChild(node, FTPConstants.FTP_DELETE_PROCESSED_FILES, null, false);
        int portValue = 21;
        if (port != null) {
            try {
                portValue = Integer.parseInt(port.getTextContent());
            } catch (NumberFormatException e) {
                portValue=0;
            }
        }
        FTPConnectionInfo result = new FTPConnectionInfo(server != null ? server.getTextContent()
                : null, portValue, user != null ? user.getTextContent() : null,
                password != null ? password.getTextContent() : null, directory != null ? directory
                        .getTextContent() : "/", connectionMode != null ? connectionMode
                        .getTextContent() : null, transferType != null ? transferType
                        .getTextContent() : null, attempt, delay, deleteProcessedFile != null ? Boolean.valueOf(deleteProcessedFile.getTextContent()) : false);
        result.validate();
        return result;
    }

    public static FTPConnectionInfo buildFTPConnectionInfo(ConfigurationExtensions extensions, int attempt, long delay)
            throws MissingElementException {
        String server = null;
        String user = null;
        String password = null;
        String directory = null;
        int port = 21;
        String connectionMode = null;
        String transferType = null;
        boolean deleteProcessedFile = false;

        server = extensions.get(FTPConstants.FTP_SERVER);
        try {
            port = Integer.parseInt(extensions.get(FTPConstants.FTP_PORT));
        } catch (NumberFormatException e) {
            // managed by validate()
        }
        user = extensions.get(FTPConstants.FTP_USER);
        password = extensions.get(FTPConstants.FTP_PASSWORD);
        directory = extensions.get(FTPConstants.FTP_FOLDER);
        connectionMode = extensions.get(FTPConstants.CONNECTION_MODE);
        transferType = extensions.get(FTPConstants.TRANSFER_TYPE);
        deleteProcessedFile = Boolean.valueOf(extensions.get(FTPConstants.FTP_DELETE_PROCESSED_FILES)); 
        FTPConnectionInfo result = new FTPConnectionInfo(server, port, user, password, directory,
                connectionMode, transferType, attempt, delay, deleteProcessedFile);
        result.validate();
        return result;
    }

}
